#
# spec file for package libqt5-qtwebsockets
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define qt5_snapshot 1
%define libname libQt5WebSockets5
%define base_name libqt5
%define real_version 5.15.11
%define so_version 5.15.11
%define tar_version qtwebsockets-everywhere-src-%{version}
Name:           libqt5-qtwebsockets
Version:        5.15.11+kde2
Release:        1.1
Summary:        Qt 5 WebSockets Library
License:        LGPL-3.0-only OR  (GPL-2.0-only OR GPL-3.0-or-later)
Group:          Development/Libraries/X11
URL:            https://www.qt.io
Source:         %{tar_version}.tar.xz
Source1:        baselibs.conf
BuildRequires:  libQt5Core-private-headers-devel >= %{real_version}
BuildRequires:  pkgconfig
BuildRequires:  xz
BuildRequires:  pkgconfig(Qt5Core) >= %{real_version}
BuildRequires:  pkgconfig(Qt5Network) >= %{real_version}
BuildRequires:  pkgconfig(Qt5Qml) >= %{real_version}
BuildRequires:  pkgconfig(Qt5Quick) >= %{real_version}
BuildRequires:  pkgconfig(Qt5Sql) >= %{real_version}
BuildRequires:  pkgconfig(openssl)
%if %{qt5_snapshot}
#to create the forwarding headers
BuildRequires:  perl
%endif

%description
The Qt WebSockets module provides C++ and QML interfaces that enable
Qt applications to act as a server that can process WebSocket
requests, or a client that can consume data received from the server,
or both.

%prep
%autosetup -p1 -n %{tar_version}

%package -n %{libname}
Summary:        Qt 5 WebSockets Library
Group:          Development/Libraries/X11
%requires_ge    libQt5Network5

%description -n %{libname}
The Qt WebSockets module provides C++ and QML interfaces that enable
Qt applications to act as a server that can process WebSocket
requests, or a client that can consume data received from the server,
or both.

%package -n %{libname}-imports
Summary:        QML imports for the Qt 5 WebSockets library
Group:          Development/Libraries/X11
%requires_ge    libQtQuick5
Supplements:    (%{libname} and libQtQuick5)
# imports splited with 5.4.1
Conflicts:      %{libname} < 5.4.1

%description -n %{libname}-imports
The Qt WebSockets module provides C++ and QML interfaces that enable
Qt applications to act as a server that can process WebSocket
requests, or a client that can consume data received from the server,
or both.

%package devel
Summary:        Development files for the Qt5 WebSockets library
Group:          Development/Libraries/X11
Requires:       %{libname} = %{version}

%description devel
You need this package if you want to compile programs with QtWebSockets.

%package private-headers-devel
Summary:        Non-ABI stable experimental API for the Qt5 WebSocket library
Group:          Development/Libraries/C and C++
Requires:       %{name}-devel = %{version}
Requires:       libQt5Core-private-headers-devel >= %{real_version}
BuildArch:      noarch

%description private-headers-devel
This package provides private headers of libqt5-qtwebsockets that are normally
not used by application development and that do not have any ABI or
API guarantees. The packages that build against these have to require
the exact Qt version.

%package examples
Summary:        Qt5 websockets examples
Group:          Development/Libraries/X11
License:        BSD-3-Clause
Recommends:     %{name}-devel

%description examples
Examples for the libqt5-qtwebsockets module.

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%build
%if %{qt5_snapshot}
#force the configure script to generate the forwarding headers (it checks whether .git directory exists)
mkdir .git
%endif
%qmake5
%make_jobs

%install
%qmake5_install
# kill .la files
rm -f %{buildroot}%{_libqt5_libdir}/lib*.la

%files -n %{libname}
%defattr(-,root,root,755)
%license *GPL*
%{_libqt5_libdir}/libQt5WebSockets.so.*

%files -n %{libname}-imports
%defattr(-,root,root,755)
%license *GPL*
%{_libqt5_archdatadir}/qml/Qt/WebSockets/
%{_libqt5_archdatadir}/qml/QtWebSockets/

%files private-headers-devel
%defattr(-,root,root,755)
%license *GPL*
%{_libqt5_includedir}/Qt*/%{so_version}

%files devel
%defattr(-,root,root,755)
%license *GPL*
%{_libqt5_includedir}/QtWebSockets
%exclude %{_libqt5_includedir}/Qt*/%{so_version}
%{_libqt5_includedir}/QtWebSockets
%{_libqt5_libdir}/cmake/Qt5*
%{_libqt5_libdir}/libQt5WebSockets.prl
%{_libqt5_libdir}/libQt5WebSockets.so
%{_libqt5_libdir}/pkgconfig/Qt5WebSockets.pc
%{_libqt5_archdatadir}/mkspecs/modules/*.pri

%files examples
%defattr(-,root,root,755)
%license *GPL*
%{_libqt5_examplesdir}/

%changelog
* Fri Oct  6 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.11+kde2, rebased upstream:
  * No code changes
* Tue Jun 13 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.10+kde2, rebased upstream:
  * No code changes
* Fri Apr 21 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.8+kde6, rebased upstream:
  * Fix setting of socket options
* Mon Jan  9 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.8+kde3, rebased upstream:
  * Disconnect when handshake fails
* Thu Nov  3 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.7+kde2, rebased upstream:
  * No code changes
* Mon Sep 26 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.6+kde2, rebased upstream:
  * Clear frame before emitting signals to prevent duplicating messages
* Mon Jun 27 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.5+kde3, rebased upstream:
  * Revert "Update commercial license headers"
  * Update commercial license headers
- Drop 0001-Revert-Bump-version.patch, it's versioned correctly now
* Fri Jan 21 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.2+kde7:
  * QWebSocketProtocol: fix potential UB (signed overflow) in masking operation
  * Pass ignoreSslErrors to unterlying QSslSocket
  * Clear frame on reconnect
* Tue Jun 22 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Switch to KDE's maintenance branch
- Update to version 5.15.2+kde4:
  * Add doc note about internal ping/pong handling
  * QWebSocket: websocket is a websocket, not a TLS socket necessary
  * Add changes file for Qt 5.15.2
  * Bump version
- Add patch to reset version to 5.15.2:
  * 0001-Revert-Bump-version.patch
* Fri Nov 20 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.2:
  * New bugfix release
  * For more details please see:
    http://code.qt.io/cgit/qt/qtwebsockets.git/plain/dist/changes-5.15.2/?h=5.15.2
* Thu Sep 10 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.1:
  * New bugfix release
  * For more details please see:
    http://code.qt.io/cgit/qt/qtwebsockets.git/plain/dist/changes-5.15.1/?h=5.15.1
* Tue May 26 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to version 5.15.0:
  * No changelog available
* Wed May 20 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to version 5.15.0-rc2:
  * No changelog available
* Wed May  6 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-rc:
  * New bugfix release
  * For the changes between 5.14.2 and 5.15.0 please see:
    http://code.qt.io/cgit/qt/qtwebsockets.git/plain/dist/changes-5.15.0/?h=5.15.0
* Fri Apr 24 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-beta4:
  * New bugfix release
  * No changelog available
* Tue Apr 14 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-beta3:
  * New bugfix release
  * No changelog available
* Tue Mar 24 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-beta2:
  * New bugfix release
  * No changelog available
* Fri Feb 28 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-beta1:
  * New bugfix release
  * No changelog available
* Wed Feb 19 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-alpha:
  * New feature release
  * For more details please see:
    https://wiki.qt.io/New_Features_in_Qt_5.15
* Mon Jan 27 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.1:
  * New bugfix release
  * For more details please see:
    http://code.qt.io/cgit/qt/qtwebsockets.git/plain/dist/changes-5.14.1/?h=v5.14.1
* Mon Dec 16 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update the license tags
* Thu Dec 12 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0:
  * New bugfix release
  * For the changes between 5.13.2 and 5.14.0 please see:
    https://code.qt.io/cgit/qt/qtwebsockets.git/tree/dist/changes-5.14.0?h=v5.14.0
  * For the changes between 5.13.1 and 5.13.2 please see:
    https://code.qt.io/cgit/qt/qtwebsockets.git/tree/dist/changes-5.13.2?h=v5.14.0
* Wed Dec  4 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0-rc:
  * New bugfix release
  * No changelog available
  * For more details please see:
  * For more details about Qt 5.14 please see:
    https://wiki.qt.io/New_Features_in_Qt_5.14
* Tue Nov 12 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0-beta3:
  * New bugfix release
  * No changelog available
* Thu Oct 24 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0-beta2:
  * New bugfix release
  * No changelog available
* Tue Oct 15 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0-beta1:
  * New bugfix release
  * No changelog available
* Mon Sep 30 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0-alpha:
  * New feature release
  * No changelog available
  * For more details about Qt 5.14 please see:
    https://wiki.qt.io/New_Features_in_Qt_5.14
* Fri Sep  6 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.13.1:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtwebsockets.git/plain/dist/changes-5.13.1/?h=v5.13.1
* Wed Jun 19 2019 fabian@ritter-vogt.de
- Update to 5.13.0:
  * New bugfix release
  * No changelog available
  * For more details about Qt 5.13 please see:
  * http://code.qt.io/cgit/qt/qtwebsockets.git/plain/dist/changes-5.13.0/?h=5.13
* Tue Jun  4 2019 fabian@ritter-vogt.de
- Update to 5.13.0-rc:
  * New bugfix release
  * No changelog available
* Mon Apr 29 2019 fabian@ritter-vogt.de
- Update to 5.13.0-beta2:
  * New bugfix release
  * No changelog available
* Thu Apr 18 2019 fabian@ritter-vogt.de
- Update to 5.12.3:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtwebsockets.git/plain/dist/changes-5.12.3/?h=v5.12.3
* Thu Mar 21 2019 fabian@ritter-vogt.de
- Update to 5.13.0-beta1:
  * New feature release
  * For more details about Qt 5.13 please see:
  * http://code.qt.io/cgit/qt/qtwebsockets.git/plain/dist/changes-5.13.0/?h=5.13
* Thu Mar 14 2019 fabian@ritter-vogt.de
- Update to 5.12.2:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtwebsockets.git/plain/dist/changes-5.12.2/?h=5.12.2
* Fri Feb  1 2019 fabian@ritter-vogt.de
- Update to 5.12.1:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtwebsockets.git/plain/dist/changes-5.12.1/?h=v5.12.1
* Thu Dec  6 2018 fabian@ritter-vogt.de
- Update to 5.12.0:
  * New feature release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtwebsockets.git/plain/dist/changes-5.12.0/?h=v5.12.0
* Mon Dec  3 2018 fabian@ritter-vogt.de
- Update to 5.12.0-rc2:
  * New bugfix release
  * Only important bugfixes
- Changelog for Qt 5.12.0:
  * http://code.qt.io/cgit/qt/qtwebsockets.git/plain/dist/changes-5.12.0/?h=5.12.0
* Thu Nov 22 2018 fabian@ritter-vogt.de
- Update to 5.12.0-rc:
  * New bugfix release
  * No changelog available
* Thu Nov  8 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta4:
  * New bugfix release
  * No changelog available
* Fri Oct 26 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta3:
  * New bugfix release
  * No changelog available
* Wed Oct 17 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta2:
  * New bugfix release
  * No changelog available
* Fri Oct  5 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta1:
  * New bugfix release
  * No changelog available
* Tue Oct  2 2018 fabian@ritter-vogt.de
- Update to 5.12.0-alpha:
  * New feature release
  * For more details please see:
  * http://wiki.qt.io/New_Features_in_Qt_5.12
* Fri Sep 21 2018 fabian@ritter-vogt.de
- Update to 5.11.2
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtwebsockets.git/plain/dist/changes-5.11.2/?h=v5.11.2
* Tue Jun 19 2018 fabian@ritter-vogt.de
- Update to 5.11.1
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtwebsockets.git/plain/dist/changes-5.11.1/?h=v5.11.1
* Tue May 22 2018 fabian@ritter-vogt.de
- Update to 5.11.0
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtwebsockets.git/plain/dist/changes-5.11.0/?h=v5.11.0
* Tue May  8 2018 fabian@ritter-vogt.de
- Update to 5.11.0-rc
  * New bugfix release
  * No changelog available
* Mon Apr 23 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta4
  * New bugfix release
  * No changelog available
* Wed Apr 11 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta3
  * New bugfix release
  * No changelog available
* Wed Mar 28 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta2
  * New bugfix release
  * No changelog available
* Tue Mar 13 2018 christophe@krop.fr
- Fix the license tag.
* Thu Mar  1 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta1
  * New feature release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtwebsockets.git/plain/dist/changes-5.11.0-beta1/?h=v5.11.0-beta1
* Tue Feb 20 2018 fabian@ritter-vogt.de
- Update to 5.11.0-alpha
  * New feature release
  * For more details please see:
  * https://wiki.qt.io/New_Features_in_Qt_5.11
* Wed Feb 14 2018 fabian@ritter-vogt.de
- Update to 5.10.1
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtwebsockets.git/plain/dist/changes-5.10.1/?h=v5.10.1
* Thu Jan 11 2018 opensuse@dstoecker.de
- fix Typo
* Fri Dec  8 2017 christophe@krop.fr
- Update the license tag (boo#967696)
* Thu Dec  7 2017 fabian@ritter-vogt.de
- Update to 5.10.0 final
  * New bugfix release
* Sun Dec  3 2017 fabian@ritter-vogt.de
- Update to 5.10.0 RC 2
  * New bugfix release
* Thu Nov 30 2017 fabian@ritter-vogt.de
- Update to 5.10.0 RC 1
  * New bugfix release
* Sat Nov 25 2017 fabian@ritter-vogt.de
- Update to 5.9.3
  * New bugfix release
  * For more details, see:
    http://code.qt.io/cgit/qt/qtwebsockets.git/tree/dist/changes-5.9.3/?h=v5.9.3
* Wed Nov 15 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 4
- Contains bugfixes
* Thu Nov  2 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 3
- Contains bugfixes
* Mon Oct 30 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 2
- Contains bugfixes
* Mon Oct  9 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 1
- For more information visit:
    https://blog.qt.io/blog/2017/10/09/qt-5-10-beta-released/
* Sun Oct  8 2017 lbeltrame@kde.org
- Update to 5.9.2
  * For more details please see:
    https://blog.qt.io/blog/2017/10/06/qt-5-9-2-released/
* Mon Sep 25 2017 fabian@ritter-vogt.de
- Update to 5.10 Alpha 1
- For more information visit:
    https://blog.qt.io/blog/2017/09/13/qt-5-10-alpha-released/
* Sat Jul  1 2017 lbeltrame@kde.org
- Update to 5.9.1
  * For more details please see:
    http://blog.qt.io/blog/2017/06/30/qt-5-9-1-released/
* Thu Jun  1 2017 jengelh@inai.de
- Update descriptions.
* Wed May 31 2017 fabian@ritter-vogt.de
- Update to 5.9.0 final
* Wed May 24 2017 fabian@ritter-vogt.de
- Update to 5.9.0 RC:
  * For more details please see:
    http://lists.qt-project.org/pipermail/announce/2017-May/000115.html
    and https://wiki.qt.io/New_Features_in_Qt_5.9
* Wed Dec 14 2016 hrvoje.senjan@gmail.com
- Update to 5.7.1
  * For more details please see:
    https://blog.qt.io/blog/2016/12/14/qt-5-7-1-released/
    and https://www.qt.io/qt5-7/
* Sat Sep 24 2016 hrvoje.senjan@gmail.com
- Update to 5.7.0
  * For more details please see:
    https://www.qt.io/qt5-7/
* Wed Jun  8 2016 hrvoje.senjan@gmail.com
- Update to 5.6.1
  * For more details please see:
    http://blog.qt.io/blog/2016/06/08/qt-5-6-1-released/
* Fri Mar 18 2016 hrvoje.senjan@gmail.com
- Update to 5.6.0
  * For more details please see:
    http://blog.qt.io/blog/2016/03/16/qt-5-6-released/
    and https://wiki.qt.io/New_Features_in_Qt_5.6
* Fri Oct 16 2015 hrvoje.senjan@gmail.com
- Update to 5.5.1
  * For more details please see:
    http://blog.qt.io/blog/2015/10/15/qt-5-5-1-released/
* Sun Aug 16 2015 hrvoje.senjan@gmail.com
- Update to 5.5.0
  * For more details please see:
    http://blog.qt.io/blog/2015/07/01/qt-5-5-released/
    and https://wiki.qt.io/New_Features_in_Qt_5.5
* Wed Jun  3 2015 hrvoje.senjan@gmail.com
- Update to 5.4.2
  * Bugfix release, for more details please see:
    http://blog.qt.io/blog/2015/06/02/qt-5-4-2-released/
* Tue Feb 24 2015 hrvoje.senjan@gmail.com
- Update to 5.4.1
  * For more details please see:
    http://blog.qt.io/blog/2015/02/24/qt-5-4-1-released/
- Split the imports into separate package
- Add minimal requires on libQtQuick5 and libQt5Network5
* Wed Dec 10 2014 hrvoje.senjan@gmail.com
- Update to 5.4 Final
  * For more details please see:
    http://blog.qt.digia.com/blog/2014/12/10/qt-5-4-released/
    and http://qt-project.org/wiki/New-Features-in-Qt-5.4
* Thu Nov 27 2014 hrvoje.senjan@gmail.com
- Update to 5.4 RC
  * For more details please see:
    http://blog.qt.digia.com/blog/2014/11/27/qt-5-4-release-candidate-available/
    and http://qt-project.org/wiki/New-Features-in-Qt-5.4
* Tue Sep 16 2014 hrvoje.senjan@gmail.com
- Update to 5.3.2 final
  * No changes since previous snapshot
  * Use official tars
* Thu Sep  4 2014 hrvoje.senjan@gmail.com
- Update to 5.3.2~git20140904 (rca03374):
  * Tip of the bugfix 5.3.2 branch:
  * Use 0 instead of Q_NULLPTR in public headers.
  * Fix a typo in proxy handling.
  * Bump version
* Wed Jun 25 2014 hrvoje.senjan@gmail.com
- Update to 5.3.1
  * Bugfix release, for more details please see:
    http://blog.qt.digia.com/blog/2014/06/25/qt-5-3-1-released/
* Mon Jun  2 2014 hrvoje.senjan@gmail.com
- Added baselibs.conf
- Make private headers noarch
* Mon May 19 2014 hrvoje.senjan@gmail.com
- Update to 5.3.0 final
  * Minor bugfixes over previous RC
* Thu May  8 2014 hrvoje.senjan@gmail.com
- Update to 5.3.0 RC
  * For more details, please see
  http://blog.qt.digia.com/blog/2014/05/08/qt-5-3-release-candidate-available/
  and http://qt-project.org/wiki/New-Features-in-Qt-5.3
* Tue Mar 25 2014 hrvoje.senjan@gmail.com
- Activate libqt5-qtwebsockets package
